#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/environment-update.sh - update or generate new environment configuration
#
# Creation:     2007-10-16  hbfl
# Last Update:  $Id: environment-update.sh 13266 2008-01-13 22:54:59Z hbfl $
#
# Copyright (c) 2001-2008 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set packages name
packages_name='environment'

# include configib
. /var/install/include/configlib

#------------------------------------------------------------------------------
# set the default values for configuration
#------------------------------------------------------------------------------
EDITOR='joe'
PAGER='less'

MAX_BACKUP_CONFIG='10'
SCROLL='no'

HTTP_PROXY=''
HTTP_PROXY_USER=''
HTTP_PROXY_PASSWD=''

LC_CTYPE='de_DE@euro'

#------------------------------------------------------------------------------
# read old configuration
#------------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    test -f /etc/config.d/${packages_name} &&
        . /etc/config.d/${packages_name}

}
#------------------------------------------------------------------------------
# write default files
#------------------------------------------------------------------------------
make_default_file()
{
    internal_conf_file=${1}

    {
    #--------------------------------------------------------------------------------
    printgpl -conf ${packages_name} "2003-07-20" "fm"
    #--------------------------------------------------------------------------------

    #--------------------------------------------------------------------------------
    printgroup "Setup menu configuration"
    #--------------------------------------------------------------------------------

    printvar "EDITOR"            "joe (alternative: vi)"
    printvar "PAGER"             "less (alternative: more)"
    echo
    printvar "MAX_BACKUP_CONFIG" "maximum number of package config files"
    printvar ""                  "to backup up in /etc/backup.d"
    printvar "SCROLL"            "no:  no-scroll - show pages if lists"
    printvar ""                  "     are to long"
    printvar ""                  "yes: always show entire lists - you"
    printvar ""                  "     need to scroll manually"
    echo
    printvar "HTTP_PROXY"        "http proxy for package installer"
    printvar ""                  "(empty to disable)"
    printvar ""                  "server:port"
    printvar "HTTP_PROXY_USER"   "http proxy username (emtpy to disable auth)"
    printvar "HTTP_PROXY_PASSWD" "http proxy password"

    #--------------------------------------------------------------------------------
    printgroup "Localisation"
    #--------------------------------------------------------------------------------

    printvar "LC_CTYPE"          "locale setting (don't change yet)"

    #--------------------------------------------------------------------------------
    printend
    #--------------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}

}
#------------------------------------------------------------------------------
# write config files
#------------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}

    if ! grep -q ^SCROLL ${internal_conf_file}
    then

        config_entry=`grep "^HTTP_PROXY=" ${internal_conf_file}`

sed -e "/^${config_entry}/i\\
\  \\
SCROLL='no'                            # no:  no-scroll - show pages if lists \\
\                                       #      are too long \\
\                                       # yes: always show entire lists - you \\
\                                       #      need to scroll manually \\
\  " ${internal_conf_file} >${internal_conf_file}$$

        mv ${internal_conf_file}$$ ${internal_conf_file}

        # Set rights
        chmod 0600 ${internal_conf_file}
        chown root ${internal_conf_file}

    fi
}
#----------------------------------------------------------------------------
# create check.d file
#---------------------------------------------------------------------------
make_check_file()
{
printgpl -check ${packages_name} "2005-03-04" "max" >/etc/check.d/${packages_name}
cat >>/etc/check.d/${packages_name} <<EOF
# Variable             OPT_VARIABLE      VARIABLE_N     VALUE
EDITOR                 -                 -              NOBLANK
PAGER                  -                 -              NOBLANK

MAX_BACKUP_CONFIG      -                 -              NUMERIC
SCROLL                 -                 -              YESNO

HTTP_PROXY             -                 -              ENVIRONMENT_PROXY
HTTP_PROXY_USER        -                 -              ENOBLANK
HTTP_PROXY_PASSWD      -                 -              ENOBLANK

LC_CTYPE               -                 -              NOBLANK
EOF

     # Set rights for check file
    chmod 0600 /etc/check.d/${packages_name}
    chown root /etc/check.d/${packages_name}


printgpl -check_exp ${packages_name} "2006-01-11" "max" >/etc/check.d/${packages_name}.exp
cat >>/etc/check.d/${packages_name}.exp <<EOF
ENVIRONMENT_PROXY  = '()|((http://)?((RE:FQDN)|(RE:IPADDR)):(RE:PORT))(/)?'
                   : 'Invalid proxy entry, use server:port'
EOF

     # Set rights for check file
    chmod 0600 /etc/check.d/${packages_name}.exp
    chown root /etc/check.d/${packages_name}.exp
}
#------------------------------------------------------------------------------
# main
#------------------------------------------------------------------------------
# write default config file
make_default_file /etc/default.d/${packages_name}

# update from old version
rename_old_variables

# write new config file
make_config_file /etc/config.d/${packages_name}

# write check.d file
make_check_file

exit 0
#------------------------------------------------------------------------------
# end
#------------------------------------------------------------------------------
